Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(454)

Unified Diff: chrome/browser/chromeos/contacts/contact_database_unittest.cc

Issue 10896031: contacts: Add ContactManagerInterface::GetWeakPtr(). (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: apply review feedback Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/contacts/contact_database_unittest.cc
diff --git a/chrome/browser/chromeos/contacts/contact_database_unittest.cc b/chrome/browser/chromeos/contacts/contact_database_unittest.cc
index b869758106a57512a046abb88bac433f320b1fad..31f8e4055fed7a77ebced524c20d8ffc0a8dcd39 100644
--- a/chrome/browser/chromeos/contacts/contact_database_unittest.cc
+++ b/chrome/browser/chromeos/contacts/contact_database_unittest.cc
@@ -201,7 +201,7 @@ TEST_F(ContactDatabaseTest, SaveAndReload) {
EXPECT_EQ(kNewLastUpdateTime, loaded_metadata->last_update_start_time());
}
-TEST_F(ContactDatabaseTest, FullAndPartialUpdates) {
+TEST_F(ContactDatabaseTest, FullAndIncrementalUpdates) {
// Do a full update that inserts two contacts into the database.
const std::string kContactId1 = "contact_id_1";
const std::string kSharedEmail = "foo@example.org";
@@ -228,7 +228,7 @@ TEST_F(ContactDatabaseTest, FullAndPartialUpdates) {
EXPECT_EQ(VarContactsToString(2, contact1.get(), contact2.get()),
ContactsToString(*loaded_contacts));
// Do a partial update including just the second contact.
InitContact(kContactId2, "2b", false, contact2.get());
AddPostalAddress("postal_1", Contact_AddressType_Relation_HOME,
"", true, contact2.get());
@@ -240,7 +240,8 @@ TEST_F(ContactDatabaseTest, FullAndPartialUpdates) {
EXPECT_EQ(VarContactsToString(2, contact1.get(), contact2.get()),
ContactsToString(*loaded_contacts));
- // Do an empty partial update and check that the metadata is still updated.
+ // Do an empty incremental update and check that the metadata is still
+ // updated.
contacts_to_save.reset(new ContactPointers);
metadata_to_save.reset(new UpdateMetadata);
const int64 kLastUpdateTime = 1234;
@@ -228,7 +228,7 @@ TEST_F(ContactDatabaseTest, FullAndPartialUpdates) {
EXPECT_EQ(VarContactsToString(2, contact1.get(), contact2.get()),
ContactsToString(*loaded_contacts));
- // Do a partial update including just the second contact.
+ // Do an incremental update including just the second contact.
InitContact(kContactId2, "2b", false, contact2.get());
AddPostalAddress("postal_1", Contact_AddressType_Relation_HOME,
« no previous file with comments | « chrome/browser/chromeos/contacts/contact_database.cc ('k') | chrome/browser/chromeos/contacts/contact_manager.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698